import React, {useState, useEffect} from 'react'

import ShippingAddress from './ShippingAddress.js'
import PaymentMethod from './PaymentMethod.js'
import ReviewOrder from './ReviewOrder.js'
import SubmitOrder from './SubmitOrder.js'


export default function Checkout() {
    
    ///////////////////////
    // Shipping Info State
    ///////////////////////
    const [firstName, setFirstName] = useState([])
    const [lastName, setLastName] = useState([])
    const [shippingAddress, setShippingAddress] = useState([])
    const [aptSuiteNo, setAptSuiteNo] = useState([])
    const [city, setCity] = useState([])
    const [state, setState] = useState([])
    const [zipCode, setZipCode] = useState([])


    ///////////////////////
    // Billing Info State
    ///////////////////////
    const [cardNumber, setCardNumber] = useState([])
    const [cardHolderName, setCardHolderName] = useState([])
    const [expirationDate, setExpirationDate] = useState([])
    const [cvv, setCVV] = useState([])



    // This watches for changes on any shipping input field and prints the current states on any change
    useEffect( () => {
        console.log("======================================")
        console.log("First Name: " + firstName)
        console.log("Last Name: " + lastName)
        console.log("Shipping Address: " + shippingAddress)
        console.log("Apt Suite No: " + aptSuiteNo)
        console.log("City: " + city)
        console.log("State: " + state)
        console.log("Zip: " + zipCode)
    }, [firstName, lastName, shippingAddress, aptSuiteNo, city, state, zipCode])

    useEffect( () => {
        console.log("======================================")
        console.log("Card Number: " + cardNumber)
        console.log("Card Holder Name: " + cardHolderName)
        console.log("Expiration Date: " + expirationDate)
        console.log("CVV: " + cvv)
    }, [cardNumber, cardHolderName, expirationDate, cvv])


    return (
        <div id="checkout-container">

            {/* Collects User's shipping info */}
            <ShippingAddress 
                captureFirstName={setFirstName}
                captureLastName={setLastName}
                captureShippingAddress={setShippingAddress}
                captureAptSuiteNo={setAptSuiteNo}
                captureCity={setCity}
                captureState={setState}
                captureZipCode={setZipCode}
            />

            {/* Collects User's payment info */}
            <PaymentMethod 
                captureCardNumber={setCardNumber}
                captureCardHolderName={setCardHolderName}
                captureExpirationDate={setExpirationDate}
                captureCVV={setCVV}
            />

            {/* Displays info about order. Calculates price with tax / shipping applied */}
            <ReviewOrder />

            {/* Request to submit happens here, initiates input validation and sends if success */}
            <SubmitOrder />
            
        </div>
    )
}





/*
        1. Shipping Address

        2. Payment Method

        3. Review Order

        4. Submit Order
*/